[java2python] r161 committed - changes to support renamed 'compiler' subpackage.

1 view
Skip to first unread message

codesite...@google.com

unread,
Jul 14, 2010, 3:09:37 PM7/14/10
to java2pyth...@googlegroups.com
Revision: 161
Author: troy.melhase
Date: Wed Jul 14 12:03:07 2010
Log: changes to support renamed 'compiler' subpackage.
http://code.google.com/p/java2python/source/detail?r=161

Modified:
/branches/0.5/bin/j2py
/branches/0.5/java2python/compiler/__init__.py
/branches/0.5/java2python/compiler/template.py
/branches/0.5/java2python/compiler/visitor.py

=======================================
--- /branches/0.5/bin/j2py Mon Jul 12 16:39:08 2010
+++ /branches/0.5/bin/j2py Wed Jul 14 12:03:07 2010
@@ -8,7 +8,7 @@
from os.path import basename, splitext
from time import time

-from java2python.block import Module
+from java2python.compiler import Module
from java2python.config import Config
from java2python.lib.colortools import colors
from java2python.lib.transform import buildAST
=======================================
--- /branches/0.5/java2python/compiler/template.py Wed Jul 14 11:32:04 2010
+++ /branches/0.5/java2python/compiler/template.py Wed Jul 14 12:03:07 2010
@@ -1,6 +1,6 @@
#!/usr/bin/env python
# -*- coding: utf-8 -*-
-""" java2python.block.template -> Base classes for writing Python
source. """
+""" java2python.compiler.template -> Base classes for writing Python
source. """
##
# This module defines base template types. Each base class provides
# string representation methods (__str__, __repr__, dump, dumps) for
=======================================
--- /branches/0.5/java2python/compiler/visitor.py Wed Jul 14 11:32:04 2010
+++ /branches/0.5/java2python/compiler/visitor.py Wed Jul 14 12:03:07 2010
@@ -1,6 +1,6 @@
#!/usr/bin/env python
# -*- coding: utf-8 -*-
-""" java2python.block.visitor -> Base classes for walking ASTs. """
+""" java2python.compiler.visitor -> Base classes for walking ASTs. """
##
#
# This module defines the base visitor class, BaseVisitor. It

Reply all
Reply to author
Forward
0 new messages
--- /branches/0.5/java2python/compiler/__init__.py Wed Jul 14 11:32:04 2010
+++ /branches/0.5/java2python/compiler/__init__.py Wed Jul 14 12:03:07 2010
@@ -1,11 +1,11 @@
#!/usr/bin/env python
# -*- coding: utf-8 -*-
-""" java2python.block -> Visitors combined with templates to make
blocks. """
+""" java2python.compiler -> Visitors combined with templates to make
blocks. """
##
# This module defines classes which combine AST walking with source
# generation. We've put these two behaviors into separate modules,
# java2python.block.template for creating source code, and
# java2python.block.visitor for walking Antlr trees.
#
# Each of the base classes depends on the behavior of its counterpart.
# This means they're very tightly coupled and that the classes are not
@@ -19,7 +19,7 @@
#
from itertools import chain, ifilter

-from java2python.block import template, visitor
+from java2python.compiler import template, visitor
from java2python.lang import tokens
from java2python.lib import FS
@@ -1,11 +1,11 @@
# This module defines classes which combine AST walking with source
# generation. We've put these two behaviors into separate modules,
-# java2python.block.template for creating source code, and
-# java2python.block.visitor for walking Antlr trees.
+# java2python.compiler.template for creating source code, and
+# java2python.compiler.visitor for walking Antlr trees.
#
# Each of the base classes depends on the behavior of its counterpart.

=======================================